@@ -1,5 +1,4 @@
 import os
-import sys
 from argparse import Namespace
 from dataclasses import asdict, dataclass
 from typing import Optional
@@ -148,8 +147,7 @@ class CookGame(Command):
 
         print(f"Subprocess terminated with (rc: {returncode})")
 
-        if returncode != 0:
-            sys.exit(returncode)
+        return returncode
 
 
 @dataclass
@@ -202,8 +200,7 @@ class CookGameUAT(Command):
         returncode = popen_with_format(fmt, cmd)
         fmt.summary()
 
-        if returncode != 0:
-            sys.exit(returncode)
+        return returncode
 
 
 COMMANDS = [
