@@ -1,5 +1,4 @@
 import os
-import sys
 from dataclasses import dataclass
 
 from simple_parsing import choice
@@ -106,8 +105,7 @@ class RunTests(Command):
 
         print(f"Subprocess terminated with (rc: {returncode})")
 
-        if returncode != 0:
-            sys.exit(returncode)
+        return returncode
 
 
 @dataclass
@@ -160,9 +158,7 @@ class RunTestsUAT(Command):
         fmt.print_non_matching = True
         returncode = popen_with_format(fmt, cmd)
         fmt.summary()
-
-        if returncode != 0:
-            sys.exit(returncode)
+        return returncode
 
 
 COMMANDS = RunTests
